@@ -297,7 +297,7 @@ node_btplot <- function(mobobj, id = TRUE, worth = TRUE, names = TRUE,
 {
     ## node ids
     node <- nodeids(mobobj, terminal = FALSE)
-    
+
     ## get all coefficients 
     cf <- apply_to_models(mobobj, node, FUN = function(z)        
       if(worth) worth(z) else coef(z, all = FALSE, ref = TRUE))
@@ -351,10 +351,10 @@ node_btplot <- function(mobobj, id = TRUE, worth = TRUE, names = TRUE,
     rval <- function(node) {
 
       ## node index
-      id <- id_node(node)
+      idn <- id_node(node)
     
       ## dependent variable setup
-      cfi <- cf[id,]
+      cfi <- cf[idn, ]
 
       ## viewport setup
       top_vp <- viewport(layout = grid.layout(nrow = 2, ncol = 3,
@@ -362,21 +362,22 @@ node_btplot <- function(mobobj, id = TRUE, worth = TRUE, names = TRUE,
                                    heights = unit(c(1, 1), c("lines", "null"))),
                                width = unit(1, "npc"), 
                                height = unit(1, "npc") - unit(2, "lines"),
-                               name = paste("node_btplot", id, sep = ""))
+                               name = paste("node_btplot", idn, sep = ""))
       pushViewport(top_vp)
       grid.rect(gp = gpar(fill = "white", col = 0))
 
       ## main title
       top <- viewport(layout.pos.col = 2, layout.pos.row = 1)
       pushViewport(top)
-      mainlab <- paste(ifelse(id, paste("Node", id, "(n = "), ""),
+      mainlab <- paste(ifelse(id, paste("Node", idn, "(n = "), ""),
         	       info_node(node)$nobs, ifelse(id, ")", ""), sep = "")
       grid.text(mainlab)
       popViewport()
 
       ## actual plot  
       plot_vpi <- viewport(layout.pos.col = 2, layout.pos.row = 2,
-        xscale = xscale, yscale = yscale, name = paste("node_btplot", id, "plot", sep = ""))
+        xscale = xscale, yscale = yscale,
+        name = paste("node_btplot", idn, "plot", sep = ""))
       pushViewport(plot_vpi)
 
       grid.lines(xscale, c(cf_ref, cf_ref), gp = gpar(col = refcol), default.units = "native")
@@ -397,3 +398,115 @@ node_btplot <- function(mobobj, id = TRUE, worth = TRUE, names = TRUE,
     return(rval)
 }
 class(node_btplot) <- "grapcon_generator"
+
+
+## MPT plot visualization function
+node_mptplot <- function(mobobj, id = TRUE,
+  names = TRUE, abbreviate = TRUE, index = TRUE, ref = TRUE,
+  col = "black", linecol = "lightgray", cex = 0.5, pch = 19, xscale = NULL,
+  yscale = c(0, 1), ylines = 1.5)
+{
+    ## node ids
+    node <- nodeids(mobobj, terminal = FALSE)
+
+    ## get all coefficients
+    cf <- apply_to_models(mobobj, node, coef)
+    cf <- do.call("rbind", cf)
+    rownames(cf) <- node
+
+    ## reference
+    if(ref)
+      cf_ref <- 1/2
+
+    ## labeling
+    if(is.character(names)) {
+      colnames(cf) <- names
+      names <- TRUE
+    }
+    if(is.character(index)) {
+      cf <- cf[, index]  # reorder labels
+      index <- TRUE
+    }
+
+    ## abbreviation
+    if(is.logical(abbreviate)) {
+      nlab <- max(nchar(colnames(cf)))
+      abbreviate <- if(abbreviate)
+        as.numeric(cut(nlab, c(-Inf, 1.5, 4.5, 7.5, Inf))) else nlab
+    }
+    colnames(cf) <- abbreviate(colnames(cf), abbreviate)
+
+    if(index) {
+      x <- seq_len(NCOL(cf))
+      if(is.null(xscale)) {
+        if (length(x) > 1) xscale <- range(x) + c(-0.1, 0.1) * diff(range(x))
+        else xscale <- c(1 - 0.1, 1 + 0.1)
+      }
+    } else {
+      x <- rep(0, NCOL(cf))
+      if(is.null(xscale)) xscale <- c(-1, 1)
+    }
+    if(is.null(yscale)) {
+      if (length(cf) > 1) yscale <- range(cf) + c(-0.1, 0.1) * diff(range(cf))
+      else yscale <- c(cf - 0.1, cf + 0.1)
+    }
+
+    ## panel function for mpt plots in nodes
+    rval <- function(node) {
+
+      ## node index
+      idn <- id_node(node)
+
+      ## dependent variable setup
+      cfi <- setNames(cf[idn, ], colnames(cf))
+
+      ## viewport setup
+      top_vp <- viewport(layout = grid.layout(nrow = 2, ncol = 3,
+                         widths = unit(c(ylines, 1, 1),
+                                       c("lines", "null", "lines")),
+                         heights = unit(c(1, 1), c("lines", "null"))),
+                         width = unit(1, "npc"),
+                         height = unit(1, "npc") - unit(2, "lines"),
+                         name = paste("node_mptplot", idn, sep = ""))
+      pushViewport(top_vp)
+      grid.rect(gp = gpar(fill = "white", col = 0))
+
+      ## main title
+      top <- viewport(layout.pos.col = 2, layout.pos.row = 1)
+      pushViewport(top)
+      mainlab <- paste(ifelse(id, paste("Node", idn, "(n = "), ""),
+                       info_node(node)$nobs, ifelse(id, ")", ""), sep = "")
+      grid.text(mainlab)
+      popViewport()
+
+      ## actual plot  
+      plot_vpi <- viewport(layout.pos.col = 2, layout.pos.row = 2,
+        xscale = xscale, yscale = yscale,
+        name = paste("node_mptplot", idn, "plot", sep = ""))
+      pushViewport(plot_vpi)
+
+      grid.lines(xscale, c(cf_ref, cf_ref), gp = gpar(col = linecol),
+                 default.units = "native")
+      if(index) {
+        grid.lines(x, cfi, gp = gpar(col = col, lty = 2),
+                   default.units = "native")
+        grid.points(x, cfi, gp = gpar(col = col, cex = cex), pch = pch,
+                    default.units = "native")
+        grid.xaxis(at = x, label = if(names) names(cfi) else x)
+      } else {
+        if(names) grid.text(names(cfi), x = x, y = cfi,
+                            default.units = "native")
+          else grid.points(x, cfi, gp = gpar(col = col, cex = cex),
+                           pch = pch, default.units = "native")
+      }
+      grid.yaxis(at = c(ceiling(yscale[1] * 100)/100,
+                        floor(yscale[2] * 100)/100))
+      grid.rect(gp = gpar(fill = "transparent"))
+
+      upViewport(2)
+    }
+
+    return(rval)
+}
+class(node_mptplot) <- "grapcon_generator"
+
